require "spec_helper"

describe Noa::Resource::BaseHelper do
  let (:post) { FactoryGirl.create(:post) }

  before do
    @controller = PostsController.new
    @controller.request = ActionDispatch::TestRequest.new
    @controller.instance_variable_set("@post", post)
  end

  describe "#resource_human_name" do
    it "returns humanized resource name" do
      expect(helper.resource_human_name).to eql("Post")
    end

    it "returns localized resource name" do
      expect(helper.resource_human_name).to eql("Post")
    end
  end
  
  describe "#resource_human_name_for" do
    it "returns humanized resource name" do
      expect(helper.resource_human_name_for(:post)).to eql("Post")
    end

    it "returns localized resource name" do
      expect(helper.resource_human_name_for(:post)).to eql("Post")
    end
  end

  describe "#resource_title" do
    it "returns resource title" do
      expect(helper.resource_title).to eql("Post #{post.id}")
    end
  end
  
  describe "#collection_title" do
    it "returns collection title" do
      expect(helper.collection_title).to eql("Posts")
    end
  end
  
  describe "#resource_action" do
    context "with action_name :new" do
      it "returns new resource title" do
        expect(helper.resource_action(:new)).to eql("New Post")
      end
    end
    
    context "with action_name :edit" do
      it "returns edit resource title" do
        expect(helper.resource_action(:edit)).to eql("Edit Post")
      end
    end
    
    context "with action_name :delete" do
      it "returns delete resource title" do
        expect(helper.resource_action(:delete)).to eql("Delete Post")
      end
    end
    
    context "with a custom action_name" do
      it "returns custom resource title" do
        expect(helper.resource_action(:lorem_ipsum)).to eql("Lorem Ipsum Post")
      end
    end
  end
end
